@@ -21,7 +21,8 @@ import inspect
 import datetime
 from time import time
 from functools import wraps
-from .commons import commons
+from inspect import isasyncgenfunction
+from .commons import Namespace
 
 
 class DebugTools:
@@ -407,6 +408,15 @@ class AsyncGenDebugTools(AsyncDebugTools):
                 raise error
         self.time_after = time()
 
+    @staticmethod
+    async def aprint_trace_call():
+        """
+        Displays the name of the function which has called the wrapped
+        async function in user code by inspecting the stack.
+        """
+        calling_function = inspect.stack()[7][3], inspect.stack()[2][3]
+        print(f"Calling Function: {calling_function}\n\n")
+
 
 class GenDebugTools(DebugTools):
     _sync_non_none_error = (
@@ -458,6 +468,15 @@ class GenDebugTools(DebugTools):
                 raise error
         self.time_after = time()
 
+    @staticmethod
+    def print_trace_call():
+        """
+        Displays the name of the function which has called the wrapped
+        async function in user code by inspecting the stack.
+        """
+        calling_function = inspect.stack()[5][3], inspect.stack()[2][3]
+        print(f"Calling Function: {calling_function}\n\n")
+
 
 def agen_timer(decorated_func):
     """
@@ -480,12 +499,11 @@ def agen_timer(decorated_func):
 
     debugger = AsyncGenDebugTools()
 
-    @comprehension()
     def wrapped_generator_func(*a, **kw):
         debugger.timed_func = decorated_func
         debugger.generator = decorated_func(*a, **kw)
         return wraps(decorated_func)(
-            debugger._agen_wrapper(*a, **kw)
+            comprehension()(debugger._agen_wrapper(*a, **kw))
         )()
 
     return wrapped_generator_func
@@ -540,7 +558,6 @@ def gen_timer(decorated_func):
 
     debugger = GenDebugTools()
 
-    @comprehension()
     def wrapped_generator_func(*a, **kw):
         debugger.timed_func = decorated_func
         debugger.generator = decorated_func(*a, **kw)
@@ -612,5 +629,5 @@ __extras = {
 }
 
 
-debuggers = commons.Namespace.make_module("debuggers", mapping=__extras)
+debuggers = Namespace.make_module("debuggers", mapping=__extras)
 
